@@ -1,18 +1,25 @@
 package clickhouse_test
 
 import (
+	"context"
 	"database/sql"
 	"flag"
 	"fmt"
+	"github.com/xo/dburl"
+	"github.com/xo/usql/drivers"
 	"log"
 	"os"
 	"path/filepath"
 	"testing"
+	"time"
 
 	dt "github.com/ory/dockertest/v3"
 	"github.com/xo/usql/drivers/clickhouse"
 	"github.com/xo/usql/drivers/metadata"
 	"github.com/yookoala/realpath"
+
+	_ "github.com/xo/usql/drivers/csvq"
+	_ "github.com/xo/usql/drivers/moderncsqlite"
 )
 
 // db is the database connection.
@@ -59,7 +66,7 @@ func doMain(m *testing.M, cleanup bool) (int, error) {
 	if cleanup {
 		defer func() {
 			if err := pool.Purge(db.res); err != nil {
-				fmt.Fprintf(os.Stderr, "error: could not purge resoure: %v\n", err)
+				fmt.Fprintf(os.Stderr, "error: could not purge resource: %v\n", err)
 			}
 		}()
 	}
@@ -85,7 +92,7 @@ func TestSchemas(t *testing.T) {
 	if err != nil {
 		t.Fatalf("could not read schemas: %v", err)
 	}
-	checkNames(t, "schema", res, "default", "system", "tutorial", "tutorial_unexpected", "INFORMATION_SCHEMA", "information_schema")
+	checkNames(t, "schema", res, "default", "system", "tutorial", "tutorial_unexpected", "INFORMATION_SCHEMA", "information_schema", "copy_test")
 }
 
 func TestTables(t *testing.T) {
@@ -119,6 +126,75 @@ func TestColumns(t *testing.T) {
 	checkNames(t, "column", res, colNames()...)
 }
 
+func TestCopy(t *testing.T) {
+	// Tests with csvq source DB. That driver doesn't support ScanType()
+	for _, destTableSpec := range []string{
+		"copy_test.dest",
+		"copy_test.dest(StringCol, NumCol)",
+		"insert into copy_test.dest values(?, ?)",
+	} {
+		t.Run("csvq_"+destTableSpec, func(t *testing.T) {
+			testCopy(t, destTableSpec, "csvq:.")
+		})
+	}
+	// Test with a driver that supports ScanType()
+	t.Run("sqlite", func(t *testing.T) {
+		testCopy(t, "copy_test.dest", "moderncsqlite://:memory:")
+	})
+}
+
+func testCopy(t *testing.T, destTableSpec string, sourceDbUrlStr string) {
+	ctx, cancel := context.WithTimeout(context.Background(), 30*time.Second)
+	defer cancel()
+	_, err := db.db.ExecContext(ctx, "truncate table copy_test.dest")
+	if err != nil {
+		t.Fatalf("could not truncate copy_test table: %v", err)
+	}
+	// Prepare copy destination URL
+	port := db.res.GetPort("9000/tcp")
+	dbUrlStr := fmt.Sprintf("clickhouse://127.0.0.1:%s", port)
+	dbUrl, err := dburl.Parse(dbUrlStr)
+	if err != nil {
+		t.Fatalf("could not parse clickhouse url %s: %v", dbUrlStr, err)
+	}
+	// Prepare source data
+	sourceDbUrl, err := dburl.Parse(sourceDbUrlStr)
+	if err != nil {
+		t.Fatalf("could not parse source DB url %s: %v", sourceDbUrlStr, err)
+	}
+	sourceDb, err := drivers.Open(ctx, sourceDbUrl, nil, nil)
+	if err != nil {
+		t.Fatalf("could not open sourceDb: %v", err)
+	}
+	defer sourceDb.Close()
+	rows, err := sourceDb.QueryContext(ctx, "select 'string', 1")
+	if err != nil {
+		t.Fatalf("could not retrieve source rows: %v", err)
+	}
+	// Do Copy, ignoring copied rows count because clickhouse driver doesn't report RowsAffected
+	_, err = drivers.Copy(ctx, dbUrl, nil, nil, rows, destTableSpec)
+	if err != nil {
+		t.Fatalf("copy failed: %v", err)
+	}
+	rows, err = db.db.QueryContext(ctx, "select StringCol, NumCol from copy_test.dest")
+	if err != nil {
+		t.Fatalf("failed to query: %v", err)
+	}
+	defer rows.Close()
+	var copiedString string
+	var copiedNum int
+	if !rows.Next() {
+		t.Fatalf("nothing copied")
+	}
+	err = rows.Scan(&copiedString, &copiedNum)
+	if err != nil {
+		t.Fatalf("could not read copied data: %v", err)
+	}
+	if copiedString != "string" || copiedNum != 1 {
+		t.Fatalf("copied data differs: %s != string, %d != 1", copiedString, copiedNum)
+	}
+}
+
 func checkNames(t *testing.T, typ string, res interface{ Next() bool }, exp ...string) {
 	n := make(map[string]bool)
 	for _, s := range exp {
@@ -798,7 +874,6 @@ func funcNames() []string {
 		"max2",
 		"maxIntersections",
 		"maxIntersectionsPosition",
-		"maxMap",
 		"maxMappedArrays",
 		"meanZTest",
 		"median",
@@ -818,7 +893,6 @@ func funcNames() []string {
 		"mid",
 		"min",
 		"min2",
-		"minMap",
 		"minMappedArrays",
 		"minSampleSizeContinous",
 		"minSampleSizeConversion",
@@ -1143,7 +1217,6 @@ func funcNames() []string {
 		"sum",
 		"sumCount",
 		"sumKahan",
-		"sumMap",
 		"sumMapFiltered",
 		"sumMapFilteredWithOverflow",
 		"sumMapWithOverflow",
@@ -1435,6 +1508,7 @@ func colNames() []string {
 		"CLID",
 		"ClientEventTime",
 		"ClientIP",
+		"ClientIP",
 		"ClientIP6",
 		"ClientTimeZone",
 		"CodeVersion",
