@@ -6,17 +6,14 @@ package sapase
 import (
 	"context"
 	"errors"
-	"regexp"
 	"strconv"
 	"strings"
 
 	"github.com/thda/tds" // DRIVER: tds
-	"github.com/xo/dburl"
 	"github.com/xo/usql/drivers"
 )
 
 func init() {
-	endRE := regexp.MustCompile(`;?\s*$`)
 	drivers.Register("tds", drivers.Driver{
 		AllowMultilineComments:  true,
 		RequirePreviousPassword: true,
@@ -49,10 +46,6 @@ func init() {
 		IsPasswordErr: func(err error) bool {
 			return strings.Contains(err.Error(), "Login failed")
 		},
-		Process: func(_ *dburl.URL, prefix string, sqlstr string) (string, string, bool, error) {
-			sqlstr = endRE.ReplaceAllString(sqlstr, "")
-			typ, q := drivers.QueryExecType(prefix, sqlstr)
-			return typ, sqlstr, q, nil
-		},
+		Process: drivers.StripTrailingSemicolon,
 	})
 }
