@@ -6,11 +6,13 @@ package sqlserver
 
 import (
 	"context"
+	"database/sql"
 	"fmt"
 	"io"
 	"strconv"
 	"strings"
 
+	mssql "github.com/microsoft/go-mssqldb"
 	sqlserver "github.com/microsoft/go-mssqldb" // DRIVER
 	"github.com/xo/usql/drivers"
 	"github.com/xo/usql/drivers/metadata"
@@ -59,6 +61,16 @@ func init() {
 			_, err := db.Exec(`ALTER LOGIN ` + user + ` WITH password = '` + newpw + `' old_password = '` + oldpw + `'`)
 			return err
 		},
+		ColumnTypes: func(col *sql.ColumnType) (interface{}, error) {
+			switch col.DatabaseTypeName() {
+			case "UNIQUEIDENTIFIER":
+				if nullable, ok := col.Nullable(); ok && nullable {
+					return new(NullUniqueIdentifier), nil
+				}
+				return new(mssql.UniqueIdentifier), nil
+			}
+			return new(interface{}), nil
+		},
 		Err: func(err error) (string, string) {
 			if e, ok := err.(sqlserver.Error); ok {
 				return strconv.Itoa(int(e.Number)), e.Message
@@ -83,3 +95,27 @@ func init() {
 func placeholder(n int) string {
 	return fmt.Sprintf("@p%d", n)
 }
+
+type NullUniqueIdentifier struct {
+	ID    mssql.UniqueIdentifier
+	Valid bool
+}
+
+func (nui *NullUniqueIdentifier) Scan(v interface{}) error {
+	nui.Valid = false
+	if v == nil {
+		return nil
+	}
+	if err := nui.ID.Scan(v); err != nil {
+		return err
+	}
+	nui.Valid = true
+	return nil
+}
+
+func (nui NullUniqueIdentifier) String() string {
+	if nui.Valid {
+		return nui.ID.String()
+	}
+	return ""
+}
