@@ -15,6 +15,7 @@ import (
 	"strings"
 	"unicode/utf8"
 
+	"github.com/kenshaw/rasterm"
 	"github.com/xo/dburl/passfile"
 	"github.com/xo/usql/text"
 )
@@ -200,13 +201,13 @@ func Shell(s string) error {
 }
 
 // Pipe starts a command and returns its input for writing.
-func Pipe(c string) (io.WriteCloser, *exec.Cmd, error) {
+func Pipe(stdout, stderr io.Writer, c string) (io.WriteCloser, *exec.Cmd, error) {
 	shell, param := Getshell()
 	if shell == "" {
 		return nil, nil, text.ErrNoShellAvailable
 	}
 	cmd := exec.Command(shell, param, c)
-	cmd.Stdout, cmd.Stderr = os.Stdout, os.Stderr
+	cmd.Stdout, cmd.Stderr = stdout, stderr
 	out, err := cmd.StdinPipe()
 	if err != nil {
 		return nil, nil, err
@@ -322,3 +323,11 @@ func Unquote(u *user.User, exec bool, v Vars) func(string, bool) (bool, string,
 		return true, res, nil
 	}
 }
+
+// TermGraphics returns the [rasterm.TermType] based on TERM_GRAPHICS
+// environment variable.
+func TermGraphics() rasterm.TermType {
+	var typ rasterm.TermType
+	_ = typ.UnmarshalText([]byte(Get("TERM_GRAPHICS")))
+	return typ
+}
