@@ -14,6 +14,7 @@ import (
 	"os"
 	"path/filepath"
 	"regexp"
+	"slices"
 	"sort"
 	"strings"
 	"time"
@@ -126,7 +127,7 @@ func loadDrivers(wd string) error {
 			return nil
 		}
 		m := dirRE.FindAllStringSubmatch(n, -1)
-		if m == nil || m[0][1] != m[0][2] || contains(skipDirs, m[0][1]) {
+		if m == nil || m[0][1] != m[0][2] || slices.Contains(skipDirs, m[0][1]) {
 			return nil
 		}
 		tag, dest := m[0][1], mostDrivers
@@ -369,12 +370,13 @@ func buildDriverTable(includeTagSummary bool) string {
 }
 
 var baseOrder = map[string]int{
-	"postgres":  0,
-	"mysql":     1,
-	"sqlserver": 2,
-	"oracle":    3,
-	"sqlite3":   4,
-	"csvq":      5,
+	"postgres":   0,
+	"mysql":      1,
+	"sqlserver":  2,
+	"oracle":     3,
+	"sqlite3":    4,
+	"clickhouse": 5,
+	"csvq":       6,
 }
 
 func buildRows(m map[string]DriverInfo, widths []int) ([][]string, []int) {
@@ -426,6 +428,10 @@ func buildAliases(v DriverInfo) string {
 			aliases[i] = v.Driver
 		}
 	}
+	fileTypes := dburl.FileTypes()
+	if slices.Contains(fileTypes, name) {
+		aliases = append(aliases, `file`)
+	}
 	if len(aliases) > 0 {
 		return "`" + strings.Join(aliases, "`, `") + "`"
 	}
@@ -513,19 +519,3 @@ const licenseTextGo = `package text
 // License contains the license text for usql.
 const License = ` + "`%s`" + `
 `
-
-func contains(v []string, n string) bool {
-	for _, s := range v {
-		if s == n {
-			return true
-		}
-	}
-	return false
-}
-
-func max(a, b int) int {
-	if a > b {
-		return a
-	}
-	return b
-}
